@@ -14,11 +14,14 @@
 # along with Pwman3; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # ============================================================================
-# Copyright (C) 2012 Oz Nahum <nahumoz@gmail.com>
+# Copyright (C) 2020 Oz N Tiram <oz.tiram@gmail.com>
 # ============================================================================
 # Copyright (C) 2006 Ivan Kelly <ivan@ivankelly.net>
 # ============================================================================
+
 from pwman.util.crypto_engine import CryptoEngine
+
+
 __DB_FORMAT__ = 0.6
 
 
@@ -41,7 +44,7 @@ class Database(object):
         enc = CryptoEngine.get()
         key = self.loadkey()
         if key is not None:
-            enc.set_cryptedkey(key)
+            enc.set_salt_digest(key)
         else:
             self.get_user_password()
 
@@ -156,42 +159,42 @@ class Database(object):
         self._con.commit()
 
     def getnodes(self, ids):
-        if ids:
-            sql = ("SELECT * FROM NODE WHERE ID IN ({})"
-                   "".format(','.join(self._sub for i in ids)))
-        else:
-            sql = "SELECT * FROM NODE"
-        self._cur.execute(sql, (ids))
-        nodes = self._cur.fetchall()
-        if not nodes:
-            return []
-        # sqlite returns nodes as bytes, postgresql returns them as str
-        if isinstance(nodes[0][1], str):
-            nodes = [node for node in nodes]
-        nodes_w_tags = []
-        for node in nodes:
+        g = self.lazy_get_nodes(ids)
+        for node in g:
             tags = [t for t in self._get_node_tags(node)]
-            nodes_w_tags.append(list(node) + tags)
+            yield list(node[0:]) + tags
 
-        return nodes_w_tags
+    def get_node(self, id):
+        node = next(self.lazy_get_nodes([id]))
+        tags = [t for t in self._get_node_tags(node)]
+        return list(node[0:]) + tags
 
-    def listnodes(self, filter=None):
-        """return a list of node ids"""
+    def lazy_get_nodes(self, ids):
+        """
+        iterates thought ids and yield a node for each id
+        """
+        query = self._get_node_sql
+        for id_ in ids:
+            if id_:
+                self._cur.execute(query, (str(id_),))
+                node = self._cur.fetchone()
+                if node:
+                    yield node
+
+    def lazy_list_node_ids(self, filter=None):
+        """return a generator that yields the node ids"""
+        # self._con.set_trace_callback(print)
         if not filter:
             sql_all = "SELECT ID FROM NODE"
             self._cur.execute(sql_all)
-            ids = self._cur.fetchall()
-            return [id[0] for id in ids]
         else:
             tagid = self._get_tag(filter)
             if not tagid:
-                return []  # pragma: no cover
-
-            # will this work for many nodes??? with the same tag?
+                yield []  # pragma: no cover
             self._cur.execute(self._list_nodes_sql, (tagid,))
-            self._con.commit()
-            ids = self._cur.fetchall()
-            return [id[0] for id in ids]
+
+        for node_id in self._cur.fetchall():
+            yield node_id[0]
 
     def add_node(self, node):
         node_tags = list(node)
